@@ -72,8 +72,6 @@ end_test ()
 
 START_TEST(test_init)
 {
-    g_type_init ();
-
     g_debug("%s", G_STRFUNC);
     auth_service = signon_auth_service_new ();
     main_loop = g_main_loop_new (NULL, FALSE);
@@ -116,8 +114,6 @@ signon_query_methods_cb (SignonAuthService *auth_service, gchar **methods,
 
 START_TEST(test_query_methods)
 {
-    g_type_init ();
-
     g_debug("%s", G_STRFUNC);
     if(!main_loop)
         main_loop = g_main_loop_new (NULL, FALSE);
@@ -187,8 +183,6 @@ signon_query_mechanisms_cb_fail (SignonAuthService *auth_service,
 
 START_TEST(test_query_mechanisms)
 {
-    g_type_init ();
-
     g_debug("%s", G_STRFUNC);
     auth_service = signon_auth_service_new ();
 
@@ -254,8 +248,6 @@ test_auth_session_query_mechanisms_cb (SignonAuthSession *self,
 
 START_TEST(test_auth_session_query_mechanisms)
 {
-    g_type_init();
-
     GError *err = NULL;
 
     g_debug("%s", G_STRFUNC);
@@ -330,7 +322,6 @@ test_auth_session_query_mechanisms_nonexisting_cb (SignonAuthSession *self,
 
 START_TEST(test_auth_session_query_mechanisms_nonexisting)
 {
-    g_type_init();
     GError *err = NULL;
 
     g_debug("%s", G_STRFUNC);
@@ -413,8 +404,9 @@ test_auth_session_process_cb (SignonAuthSession *self,
 
 START_TEST(test_auth_session_creation)
 {
-    g_type_init();
     GError *err = NULL;
+    gpointer auth_session_sentinel;
+    gpointer idty_sentinel;
 
     g_debug("%s", G_STRFUNC);
     SignonIdentity *idty = signon_identity_new(NULL, NULL);
@@ -426,12 +418,15 @@ START_TEST(test_auth_session_creation)
 
     fail_unless (auth_session != NULL, "Cannot create AuthSession object");
 
+    g_object_add_weak_pointer (G_OBJECT (idty), &idty_sentinel);
+    g_object_add_weak_pointer (G_OBJECT (auth_session), &auth_session_sentinel);
+
     g_object_unref (idty);
     fail_unless (SIGNON_IS_IDENTITY(idty), "Identity must stay untill all its session are not destroyed");
     g_object_unref (auth_session);
 
-    fail_if (SIGNON_IS_AUTH_SESSION(auth_session), "AuthSession is not synchronized with parent Identity");
-    fail_if (SIGNON_IS_IDENTITY(idty), "Identity is not synchronized with its AuthSession");
+    fail_if (auth_session_sentinel != NULL, "AuthSession is not synchronized with parent Identity");
+    fail_if (idty_sentinel != NULL, "Identity is not synchronized with its AuthSession");
 
     g_clear_error(&err);
 }
@@ -439,7 +434,6 @@ END_TEST
 
 START_TEST(test_auth_session_process)
 {
-    g_type_init();
     gint state_counter = 0;
     GError *err = NULL;
 
@@ -552,8 +546,6 @@ START_TEST(test_auth_session_process_failure)
 
     g_debug("%s", G_STRFUNC);
 
-    g_type_init ();
-
     auth_session = signon_auth_session_new (0, "nonexisting-method", &error);
     fail_unless (auth_session != NULL, "Cannot create AuthSession object");
     fail_unless (error == NULL);
@@ -656,10 +648,10 @@ START_TEST(test_auth_session_process_after_store)
 {
     SignonIdentityInfo *info;
     SignonIdentity *identity;
+    const gchar *const acl[] = { "*", NULL };
 
     g_debug("%s", G_STRFUNC);
 
-    g_type_init();
     main_loop = g_main_loop_new (NULL, FALSE);
 
     identity = signon_identity_new ();
@@ -668,6 +660,7 @@ START_TEST(test_auth_session_process_after_store)
 
     info = signon_identity_info_new ();
     signon_identity_info_set_username (info, "Nice user");
+    signon_identity_info_set_access_control_list (info, acl);
 
     signon_identity_store_credentials_with_info (identity,
                                                  info,
@@ -725,6 +718,7 @@ new_identity()
 {
     SignonIdentity *identity;
     GHashTable *methods;
+    const gchar *const acl[] = { "*", NULL };
     guint id = 0;
 
     identity = signon_identity_new(NULL, NULL);
@@ -737,7 +731,7 @@ new_identity()
                                                  methods,
                                                  "caption",
                                                  NULL,
-                                                 NULL,
+                                                 acl,
                                                  0,
                                                  new_identity_store_credentials_cb,
                                                  &id);
@@ -759,8 +753,6 @@ identity_registered_cb (gpointer data)
 
 START_TEST(test_get_existing_identity)
 {
-    g_type_init ();
-
     g_debug("%s", G_STRFUNC);
 
     main_loop = g_main_loop_new (NULL, FALSE);
@@ -783,8 +775,6 @@ END_TEST
 
 START_TEST(test_get_nonexisting_identity)
 {
-    g_type_init ();
-
     g_debug("%s", G_STRFUNC);
     identity = signon_identity_new_from_db(G_MAXINT);
 
@@ -801,7 +791,8 @@ START_TEST(test_get_nonexisting_identity)
     fail_unless (error != NULL);
 
     fail_unless (error->domain == SIGNON_ERROR);
-    fail_unless (error->code == SIGNON_ERROR_IDENTITY_NOT_FOUND);
+    fail_unless (error->code == SIGNON_ERROR_IDENTITY_NOT_FOUND ||
+                 error->code == SIGNON_ERROR_PERMISSION_DENIED);
 
     end_test ();
 }
@@ -837,7 +828,6 @@ static void store_credentials_identity_cb(SignonIdentity *self,
 
 START_TEST(test_store_credentials_identity)
 {
-    g_type_init ();
     g_debug("%s", G_STRFUNC);
     SignonIdentity *idty = signon_identity_new(NULL, NULL);
     fail_unless (idty != NULL);
@@ -894,7 +884,8 @@ static void identity_verify_username_cb(SignonIdentity *self,
 
 START_TEST(test_verify_secret_identity)
 {
-    g_type_init ();
+    const gchar *const acl[] = { "*", NULL };
+
     g_debug("%s", G_STRFUNC);
     SignonIdentity *idty = signon_identity_new(NULL, NULL);
     fail_unless (idty != NULL);
@@ -914,7 +905,7 @@ START_TEST(test_verify_secret_identity)
                                                  methods,
                                                  caption,
                                                  NULL,
-                                                 NULL,
+                                                 acl,
                                                  0,
                                                  store_credentials_identity_cb,
                                                  NULL);
@@ -953,7 +944,6 @@ static void identity_remove_cb(SignonIdentity *self, const GError *error, gpoint
 
 START_TEST(test_remove_identity)
 {
-    g_type_init ();
     g_debug("%s", G_STRFUNC);
     SignonIdentity *idty = signon_identity_new();
     fail_unless (idty != NULL);
@@ -1085,6 +1075,7 @@ static void identity_info_cb(SignonIdentity *self, const SignonIdentityInfo *inf
 
 static SignonIdentityInfo *create_standard_info()
 {
+    const gchar *const acl[] = { "*", NULL };
     g_debug("%s", G_STRFUNC);
     SignonIdentityInfo *info = signon_identity_info_new ();
     signon_identity_info_set_username (info, "James Bond");
@@ -1101,14 +1092,16 @@ static SignonIdentityInfo *create_standard_info()
     signon_identity_info_set_method (info, "method1", (const gchar **)mechanisms);
     signon_identity_info_set_method (info, "method2", (const gchar **)mechanisms);
     signon_identity_info_set_method (info, "method3", (const gchar **)mechanisms);
+    signon_identity_info_set_access_control_list (info, acl);
 
     return info;
 }
 
 START_TEST(test_info_identity)
 {
+    const gchar *const acl[] = { "*", NULL };
+
     g_debug("%s", G_STRFUNC);
-    g_type_init ();
     SignonIdentity *idty = signon_identity_new();
     fail_unless (idty != NULL);
     fail_unless (SIGNON_IS_IDENTITY (idty),
@@ -1131,7 +1124,7 @@ START_TEST(test_info_identity)
                                                  methods,
                                                  "caption",
                                                  NULL,
-                                                 NULL,
+                                                 acl,
                                                  0,
                                                  store_credentials_identity_cb,
                                                  NULL);
@@ -1222,8 +1215,9 @@ static void identity_signout_signal_cb (gpointer instance, gpointer user_data)
 
 START_TEST(test_signout_identity)
 {
+    gpointer as1_sentinel, as2_sentinel;
+
     g_debug("%s", G_STRFUNC);
-    g_type_init ();
     SignonIdentity *idty = signon_identity_new();
     fail_unless (idty != NULL);
     fail_unless (SIGNON_IS_IDENTITY (idty),
@@ -1267,13 +1261,15 @@ START_TEST(test_signout_identity)
                       G_CALLBACK(identity_signout_signal_cb), &counter);
     g_signal_connect (idty2, "signout",
                       G_CALLBACK(identity_signout_signal_cb), &counter);
+    g_object_add_weak_pointer (G_OBJECT (as1), &as1_sentinel);
+    g_object_add_weak_pointer (G_OBJECT (as2), &as2_sentinel);
 
     signon_identity_signout (idty, identity_signout_cb, NULL);
     g_main_loop_run (main_loop);
 
     fail_unless (counter == 2, "Lost some of SIGNOUT signals");
-    fail_if (SIGNON_IS_AUTH_SESSION (as1), "Authsession1 was not destroyed after signout");
-    fail_if (SIGNON_IS_AUTH_SESSION (as2), "Authsession2 was not destroyed after signout");
+    fail_if (as1_sentinel != NULL, "Authsession1 was not destroyed after signout");
+    fail_if (as2_sentinel != NULL, "Authsession2 was not destroyed after signout");
 
     g_object_unref (idty);
     g_object_unref (idty2);
@@ -1284,7 +1280,6 @@ END_TEST
 
 START_TEST(test_unregistered_identity)
 {
-    g_type_init ();
     g_debug("%s", G_STRFUNC);
     SignonIdentity *idty = signon_identity_new();
     fail_unless (idty != NULL);
@@ -1324,7 +1319,6 @@ END_TEST
 START_TEST(test_unregistered_auth_session)
 {
     g_debug("%s", G_STRFUNC);
-    g_type_init ();
     SignonIdentity *idty = signon_identity_new();
     fail_unless (idty != NULL);
     fail_unless (SIGNON_IS_IDENTITY (idty),
@@ -1416,7 +1410,6 @@ START_TEST(test_regression_unref)
 
     g_debug ("%s", G_STRFUNC);
 
-    g_type_init ();
     main_loop = g_main_loop_new (NULL, FALSE);
 
     auth_session = signon_auth_session_new (0, "ssotest", &error);
